{% load static %}
<div class="footer-wrapper">
        <div class="row text-center" > 
  <div class="col-lg-12">
           
        <div>
           <hr>
           <em>This software is brought to you by:</em>
        </div>
        
        <div>
           <a href="http://www.videntity.com" title="Videntity" target=""_blank>
           <img src="{% static 'direct/img/layout/videntity-logo.png' %}"></a>
        </div>
        
         <div>
           &copy; 2014-2015
        </div>
        
    </div>
  </div>
</div>
