{% extends "direct/base.html" %}
{% load i18n %}
{% load widget_tweaks %}
{% block content %}



    <div class="container">

      <div class="row">

        <div class="col-lg-12">
          <h1 class="page-header">{{name}} <small>{{subname}}</small></h1>
        </div>

      </div>
	  
	  <div class="row">

        <div class="col-lg-12">
          * Denotes Required Fields
        </div>

      </div>
	  

 
 
     <div class="row">
	   <div class="col-lg-10">
	    <div class="span6 offset2">
		
		<form class="well" method="post" action="">
		  {% csrf_token %}
		  <table>
			{% load bootstrap %}
			{{ form|bootstrap }}
		  </table>
	    <input type="submit" class="btn btn-primary btn-large"  value="{% trans 'Continue' %}" /><br>
	    <a href="javascript:history.go(-1)">{% trans "Go Back" %}</a>
		</form>
	  </div>
	</div>
  </div>

    </div><!-- /.container -->

  

{% endblock %}


