<!DOCTYPE html>

{% load static %}
{% get_static_prefix as STATIC_PREFIX %}
<html lang="en">
<head>


	{% load i18n %}
        <title>
        {% block pretitle %}django-direct{% endblock %}
        {% block title %} {% endblock %}
        </title>
	
    {% block head %}
        {% include "direct/include/head.html" %}
    {% endblock %}

    {% block extra_head %}
    {% endblock %}
    

</head>
<body>
      
        {% include "direct/include/top-nav.html" %}
        {% include "direct/include/messages.html" %}

      {% block content %}
         
      
        {% if template %}{% include template %}{% endif %}
        {{ content|safe }}
      {% endblock %}
    
                        
        {% include "direct/include/footer.html" %}
    <!-- JavaScript -->
    <script src="{{ STATIC_URL }}direct/modern-business/js/jquery-1.11.0.js"></script>
    <script src="{{ STATIC_URL }}direct/modern-business/js/bootstrap.js"></script>
    {% block ExtraJSFoot %}
	
	{% endblock %}
	
    
</body>

</html>