{% extends "direct/base.html" %}
{% block content %}

{% load i18n %}

    
  
<div class="container">
	  
	  
	  <div class="row">
         <div class="col-lg-8">
           {% include "include/messages.html" %}
         </div>
       </div>
</div> 
	  
	  
	  
<div class="container">     
	<div class="row">
	  <div class="col-lg-8">
	  <div class="text-center">      
		 {%if summary == "Unsure"%}
			<h1><span class="label label-warning">{{summary}}</span></h1>
	     {% elif summary == "Good"%}
			<h1><span class="label label-success">{{summary}}</span></h1>
		 {% elif summary == "Bad"%}
			<h1><span class="label label-danger">{{summary}}</span></h1>
		 {% else %}
			<h1><span class="label label-default">{{summary}}</span></h1>
		 {% endif %}
	  </div>
	   </div>
   </div>
	
   <div class="row">
	  <div class="col-lg-8">
			<hr>	  
		</div>
    </div>
			  
</div>
	  
	  
	  




<div class="container">
	  {% for h in highlights %}

	  <div class="row">
			<div class="col-lg-8">
				  <ul class="list-group">
				  {% for key, value in h.items %}	  
						<li class="list-group-item">
						  <span class="badge">{{value }}</span>
						  {{key}}
						</li>
				  {% endfor %}
				 </ul>
			
			</div>
	  </div>
	  
	   {% endfor %}
	   
	   <div class="row">
	    <div class="col-lg-8">
           <div class="text-center">
			
			
			
                  <a class="btn btn-primary btn-large" href="javascript:history.go(-1)"
                  data-toggle="tooltip" title="Back to Form">
                    <i class="fa fa-arrow-left"></i> {% trans "Back to Form" %}
                        </a>     
           </div>
		   </div>
     </div>
	   
	   
	  
</div>


  


{% endblock %}